program NLReplayOwner;

uses
  Classes, SysUtils;

var
  AppPath: String;
  Username: String;

  procedure Finish(aExitMsg: String = '');
  var
    i: Integer;
  begin
    if aExitMsg <> '' then
      WriteLn(aExitMsg);
    for i := 1 to 500 do
      Sleep(1);
    Halt;
  end;

  procedure GetUsername;
  var
    SL: TStringList;
  begin
    SL := TStringList.Create;
    try
      if not FileExists(AppPath + 'settings\settings.ini') then
        Finish('You have not configured a username in NeoLemmix.');
      SL.LoadFromFile(AppPath + 'settings\settings.ini');
      Username := SL.Values['username'];
      if (Username = '') or (Username = 'Anonymous') then
        Finish('You have not configured a username in NeoLemmix.');
    finally
      SL.Free;
    end;
  end;

  procedure FixRecursive(aBasePath: String);
  var
    SL: TStringList;
    FoundAny: Boolean;

    procedure DoFixRecursive(aRelPath: String);
    var
      SearchRec: TSearchRec;
    begin
      if FindFirst(aRelPath + '*', faDirectory, SearchRec) = 0 then
      begin
        repeat
          if (SearchRec.Name = '.') or (SearchRec.Name = '..') or ((SearchRec.Attr and faDirectory) = 0) then
            Continue;
          DoFixRecursive(aRelPath + SearchRec.Name + '\');
        until FindNext(SearchRec) <> 0;
        FindClose(SearchRec);
      end;

      if FindFirst(aRelPath + '*.nxrp', 0, SearchRec) = 0 then
      begin
        repeat
          SL.LoadFromFile(aRelPath + SearchRec.Name);
          if (SL.Count = 0) or (CompareText(LeftStr(Trim(SL[0]), 4), 'USER') <> 0) then
          begin
            FoundAny := true;
            WriteLn(aRelPath + SearchRec.Name);
            SL.Insert(0, 'USER ' + Username);
            SL.SaveToFile(aRelPath + SearchRec.Name);
          end;
        until FindNext(SearchRec) <> 0;
        FindClose(SearchRec);
      end;
    end;
  begin
    SL := TStringList.Create;
    try
      FoundAny := false;
      DoFixRecursive(aBasePath);
      if not FoundAny then
        Finish('No replays without usernames were found. Either none are present, or all already have usernames.');
    finally
      SL.Free;
    end;
  end;

begin
  AppPath := ExtractFilePath(ParamStr(0));
  GetUsername;
  if not DirectoryExists(AppPath + 'ReplayFix') then
    Finish('Please place the replays to be fixed into a folder called "ReplayFix" and try again.');
  FixRecursive(AppPath + 'ReplayFix\');
  Finish('Replay fixes complete.');
end.

